==> jc-1.4.0.tar.gz: javax/swing/colorchooser/DefaultSwatchChooserPanel.h <==
// class javax.swing.colorchooser.DefaultSwatchChooserPanel

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6c83b58ef8abc63e javax_swing_JComponent
// @dep_class 7c0c9df11a59950c javax_swing_JPanel
// @dep_class 6999b2dfcdbe6fcb javax_swing_colorchooser_AbstractColorChooserPanel
// @dep_class 633236d935c047d8 javax_swing_colorchooser_DefaultSwatchChooserPanel

// header file dependencies
// @dep_header javax_swing_colorchooser_AbstractColorChooserPanel

#include "javax/swing/colorchooser/AbstractColorChooserPanel.h"

#ifndef _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel_H_
#define _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel_H_

// Forward structure declarations
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_awt_event_MouseListener$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_Icon$object;
struct _jc_javax_swing_JColorChooser$object;
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$object;
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object;

// Typedefs
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$sub_refs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$sub_refs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$sub_nonrefs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$sub_nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$refs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$refs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$nonrefs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object;

typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$vmethods	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$vmethods;
typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$vtable	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$vtable;
typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$vtype	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$vtype;

// Constructors
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *);

// Virtual methods
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$method$buildChooser$c3b4ef0d06e57808(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *);
extern struct _jc_java_lang_String$object *_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$method$getDisplayName$ec8495f8bf7d85f4(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *);
extern struct _jc_object *_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$method$getLargeDisplayIcon$b8bd57d58f27db0a(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *);
extern struct _jc_object *_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$method$getSmallDisplayIcon$3f5a81cdb2c68338(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *);
extern struct _jc_java_lang_String$object *_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$method$getToolTipText$69909437751767f6(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *, struct _jc_java_awt_event_MouseEvent$object *);
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$method$paint$76f038a09cf0c480(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *, struct _jc_java_awt_Graphics$object *);
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$method$uninstallChooserPanel$75ee74402cc2c672(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *, struct _jc_javax_swing_JColorChooser$object *);
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$method$updateChooser$ed0d27d69b57ccc5(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$method_info$buildChooser$c3b4ef0d06e57808;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$method_info$getDisplayName$ec8495f8bf7d85f4;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$method_info$getLargeDisplayIcon$b8bd57d58f27db0a;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$method_info$getSmallDisplayIcon$3f5a81cdb2c68338;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$method_info$getToolTipText$69909437751767f6;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$method_info$paint$76f038a09cf0c480;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$method_info$uninstallChooserPanel$75ee74402cc2c672;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$method_info$updateChooser$ed0d27d69b57ccc5;

// Virtual methods structure
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$vmethods {
	void	(*buildChooser$c3b4ef0d06e57808)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *);
	struct _jc_java_lang_String$object	*(*getDisplayName$ec8495f8bf7d85f4)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *);
	struct _jc_object	*(*getLargeDisplayIcon$b8bd57d58f27db0a)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *);
	struct _jc_object	*(*getSmallDisplayIcon$3f5a81cdb2c68338)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *);
	struct _jc_java_lang_String$object	*(*getToolTipText$69909437751767f6)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *, struct _jc_java_awt_event_MouseEvent$object *);
	void	(*paint$76f038a09cf0c480)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *, struct _jc_java_awt_Graphics$object *);
	void	(*uninstallChooserPanel$75ee74402cc2c672)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *, struct _jc_javax_swing_JColorChooser$object *);
	void	(*updateChooser$ed0d27d69b57ccc5)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *);
};

// Vtable
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JPanel$vmethods	javax_swing_JPanel;
	_jc_javax_swing_colorchooser_AbstractColorChooserPanel$vmethods	javax_swing_colorchooser_AbstractColorChooserPanel;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$vmethods	javax_swing_colorchooser_DefaultSwatchChooserPanel;
};

// Vtype
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$vtype {
	_jc_type			type;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$sub_refs {
	struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$object	*mainPalette;
	struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object	*recentPalette;
	struct _jc_object	*mouseHandler;
};

// Reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$refs {
    _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$sub_refs	javax_swing_colorchooser_DefaultSwatchChooserPanel;
    _jc_javax_swing_colorchooser_AbstractColorChooserPanel$sub_refs	javax_swing_colorchooser_AbstractColorChooserPanel;
    _jc_javax_swing_JPanel$sub_refs	javax_swing_JPanel;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JPanel$sub_nonrefs	javax_swing_JPanel;
    _jc_javax_swing_colorchooser_AbstractColorChooserPanel$sub_nonrefs	javax_swing_colorchooser_AbstractColorChooserPanel;
    _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$sub_nonrefs	javax_swing_colorchooser_DefaultSwatchChooserPanel;
};

// Object instance structure
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object {
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$vtype	*vtype;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$vtype _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_colorchooser_DefaultSwatchChooserPanel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$class_object;

#endif	/* _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel_H_ */

==> jc-1.4.5.tar.gz: javax/swing/colorchooser/DefaultSwatchChooserPanel.h <==
// class javax.swing.colorchooser.DefaultSwatchChooserPanel

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c84352ee73c7cec1 javax_swing_JComponent
// @dep_class 7c0c9df11a59950c javax_swing_JPanel
// @dep_class 6999b2dfcdbe6fcb javax_swing_colorchooser_AbstractColorChooserPanel
// @dep_class a90b3472725e00f3 javax_swing_colorchooser_DefaultSwatchChooserPanel

// header file dependencies
// @dep_header javax_swing_colorchooser_AbstractColorChooserPanel

#include "javax/swing/colorchooser/AbstractColorChooserPanel.h"

#ifndef _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel_H_
#define _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel_H_

// Forward structure declarations
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_awt_event_MouseListener$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_Icon$object;
struct _jc_javax_swing_JColorChooser$object;
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$object;
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object;

// Typedefs
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$sub_refs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$sub_refs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$sub_nonrefs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$sub_nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$refs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$refs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$nonrefs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object;

typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$vmethods	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$vmethods;
typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$vtable	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$vtable;
typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$vtype	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$vtype;

// Constructors
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$method$buildChooser$c3b4ef0d06e57808(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$method$getDisplayName$ec8495f8bf7d85f4(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$method$getLargeDisplayIcon$b8bd57d58f27db0a(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$method$getSmallDisplayIcon$3f5a81cdb2c68338(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$method$getToolTipText$69909437751767f6(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$method$paint$76f038a09cf0c480(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *, struct _jc_java_awt_Graphics$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$method$uninstallChooserPanel$75ee74402cc2c672(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *, struct _jc_javax_swing_JColorChooser$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$method$updateChooser$ed0d27d69b57ccc5(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$method_info$buildChooser$c3b4ef0d06e57808;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$method_info$getDisplayName$ec8495f8bf7d85f4;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$method_info$getLargeDisplayIcon$b8bd57d58f27db0a;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$method_info$getSmallDisplayIcon$3f5a81cdb2c68338;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$method_info$getToolTipText$69909437751767f6;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$method_info$paint$76f038a09cf0c480;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$method_info$uninstallChooserPanel$75ee74402cc2c672;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$method_info$updateChooser$ed0d27d69b57ccc5;

// Virtual methods structure
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$vmethods {
	void	(*buildChooser$c3b4ef0d06e57808)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getDisplayName$ec8495f8bf7d85f4)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getLargeDisplayIcon$b8bd57d58f27db0a)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getSmallDisplayIcon$3f5a81cdb2c68338)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getToolTipText$69909437751767f6)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	void	(*paint$76f038a09cf0c480)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *, struct _jc_java_awt_Graphics$object *) _JC_JCNI_ATTR;
	void	(*uninstallChooserPanel$75ee74402cc2c672)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *, struct _jc_javax_swing_JColorChooser$object *) _JC_JCNI_ATTR;
	void	(*updateChooser$ed0d27d69b57ccc5)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JPanel$vmethods	javax_swing_JPanel;
	_jc_javax_swing_colorchooser_AbstractColorChooserPanel$vmethods	javax_swing_colorchooser_AbstractColorChooserPanel;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$vmethods	javax_swing_colorchooser_DefaultSwatchChooserPanel;
};

// Vtype
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$vtype {
	_jc_type			type;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$sub_refs {
	struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$object	*mainPalette;
	struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24RecentSwatchPanel$object	*recentPalette;
	struct _jc_object	*mouseHandler;
};

// Reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$refs {
    _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$sub_refs	javax_swing_colorchooser_DefaultSwatchChooserPanel;
    _jc_javax_swing_colorchooser_AbstractColorChooserPanel$sub_refs	javax_swing_colorchooser_AbstractColorChooserPanel;
    _jc_javax_swing_JPanel$sub_refs	javax_swing_JPanel;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JPanel$sub_nonrefs	javax_swing_JPanel;
    _jc_javax_swing_colorchooser_AbstractColorChooserPanel$sub_nonrefs	javax_swing_colorchooser_AbstractColorChooserPanel;
    _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$sub_nonrefs	javax_swing_colorchooser_DefaultSwatchChooserPanel;
};

// Object instance structure
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$object {
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$vtype	*vtype;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$vtype _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_colorchooser_DefaultSwatchChooserPanel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel$class_object;

#endif	/* _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel_H_ */
